/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DOMAINSETTINGSDIALOG_H
#define DOMAINSETTINGSDIALOG_H

// KDE Frameworks headers.
#include <KLineEdit>

// Qt toolkit headers.
#include <QDialog>
#include <QtSql>

class DomainSettingsDialog : public QDialog
{
    // Include the Q_OBJECT macro.
    Q_OBJECT

public:
    // The primary constructor.
    explicit DomainSettingsDialog(QWidget *parent = nullptr);

private Q_SLOTS:
    // The private slots.
    void apply() const;
    void cancel();
    void domainNameChanged(QString updatedDomainName) const;
    void domainSelected(QModelIndex modelIndex) const;
    void javaScriptChanged(int newIndex) const;
    void ok();
    void reset() const;
    void showAddMessageBox();
    void showDeleteMessageBox() const;

private:
    // The private functions.
    void updateUi() const;

    // The private variables.
    QPushButton *applyButtonPointer;
    QPushButton *deleteDomainButtonPointer;
    QListView *domainsListViewPointer;
    KLineEdit *domainNameLineEditPointer;
    QWidget *domainSettingsWidgetPointer;
    QSqlTableModel *domainsTableModelPointer;
    QComboBox *javaScriptComboBoxPointer;
    QPushButton *resetButtonPointer;
};
#endif
