/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BROWSERVIEW_H
#define BROWSERVIEW_H

// Qt framework headers.
#include <QPushButton>
#include <QWebEngineHistory>
#include <QWebEngineSettings>
#include <QWebEngineView>

// KDE Framework headers.
#include <KLineEdit>

class BrowserView : public QWidget
{
    // Include the Q_OBJECT macro.
    Q_OBJECT

public:
    // The primary contructor.
    explicit BrowserView(QWidget *parent);

    // The public functions.
    void applyOnTheFlyZoomFactor(const double &zoomFactor) const;
    void loadInitialWebsite();

signals:
    // The signals.
    void linkHovered(const QString &linkUrl) const;
    void userAgentUpdated(const QString &userAgent) const;
    void searchEngineUpdated(const QString &searchEngine) const;
    void zoomFactorUpdated(const double &zoomFactor) const;

public Q_SLOTS:
    // The public slots.
    void applyApplicationSettings();
    void applyDomainSettingsAndReload() const;
    void applyDomainSettingsWithoutReloading(const QString &hostname) const;
    void applyOnTheFlySearchEngine(QAction *searchEngineActionPointer);
    void applyOnTheFlyUserAgent(QAction *userAgentActionPointer) const;

private Q_SLOTS:
    // The private slots.
    void goHome() const;
    void loadUrlFromTextBox(QString urlFromUser) const;
    void pageLinkHovered(const QString &linkUrl) const;
    void toggleJavaScript() const;
    void openDomainSettings() const;
    void updateInterface() const;

private:
    // The private variables.
    QPushButton *backButtonPointer;
    QPalette domainSettingsPalette;
    QPushButton *forwardButtonPointer;
    QPushButton *javaScriptButtonPointer;
    QPalette noDomainSettingsPalette;
    QString searchEngineUrl;
    KLineEdit *urlLineEditPointer;
    QWebEngineHistory *webEngineHistoryPointer;
    QWebEngineProfile *webEngineProfilePointer;
    QWebEngineSettings *webEngineSettingsPointer;
    QWebEngineView *webEngineViewPointer;

    // The private functions.
    void applyDomainSettings(const QString &hostname, const bool reloadWebsite) const;
};
#endif
