/*
 * Copyright © 2022 Soren Stoutner <soren@stoutner.com>.
 *
 * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
 *
 * Privacy Browser PC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Privacy Browser PC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BROWSERWINDOW_H
#define BROWSERWINDOW_H

// Application headers.
#include "views/BrowserView.h"

// KDE Frameworks headers.
#include <KConfigDialog>
#include <KXmlGuiWindow>

// Qt toolkit headers.
#include <QLabel>

class BrowserWindow : public KXmlGuiWindow
{
    // Include the Q_OBJECT macro.
    Q_OBJECT

public:
    // The default constructor.
    BrowserWindow();

private Q_SLOTS:
    // The private slots.
    void fileNew() const;
    void getZoomFactorFromUser();
    void settingsConfigure();
    void updateOnTheFlySearchEngine(const QString &searchEngine) const;
    void updateOnTheFlyUserAgent(const QString &userAgent) const;
    void updateOnTheFlyZoomFactor(const double &zoomFactor);
    void updateSearchEngineLabel(const QString &searchEngineString) const;
    void updateStatusBar(const QString &statusBarMessage) const;
    void updateUserAgentLabel(const QString &userAgentName) const;

private:
    // The private variables.
    BrowserView *browserViewPointer;
    double currentZoomFactor;
    QLabel *searchEngineLabelPointer;
    QAction *searchEngineMojeekActionPointer;
    QAction *searchEngineMonoclesActionPointer;
    QAction *searchEngineMetagerActionPointer;
    QAction *searchEngineGoogleActionPointer;
    QAction *searchEngineBingActionPointer;
    QAction *searchEngineYahooActionPointer;
    QAction *searchEngineCustomActionPointer;
    QLabel *userAgentLabelPointer;
    QAction *userAgentPrivacyBrowserActionPointer;
    QAction *userAgentFirefoxLinuxActionPointer;
    QAction *userAgentChromiumLinuxActionPointer;
    QAction *userAgentFirefoxWindowsActionPointer;
    QAction *userAgentChromeWindowsActionPointer;
    QAction *userAgentEdgeWindowsActionPointer;
    QAction *userAgentSafariMacosActionPointer;
    QAction *userAgentCustomActionPointer;
    QAction *zoomFactorActionPointer;
    KConfigDialog *configDialogPointer;
};
#endif
